@@ -96,12 +96,12 @@ class Tapd:
         return OrderedDict(data)
 
     def get_tapd_test_plans(self):
-        """custom_field_2 为迭代 ID"""
+        """custom_field_2 为迭代 ID, custom_field_3 需求ID，以需求ID为key, 测试计划ID为value"""
         url = urljoin(self.base_url, '/tapd/origin/test_plans')
-        response = requests.get(url,
-                                params={'status': 'open', 'custom_field_2': self.iteration_id, 'fields': 'id,name'})
-        data = [(item['TestPlan']['name'], item['TestPlan']['id']) for item in
-                response.json().get('data', [])]
+        response = requests.get(url, params={'status': 'open', 'custom_field_2': self.iteration_id,
+                                             'fields': 'id,custom_field_3'})
+        data = [(item['TestPlan']['custom_field_3'], item['TestPlan']['id']) for item in
+                response.json().get('data', []) if item['TestPlan']['custom_field_3']]
         return OrderedDict(data)
 
     def post_tapd_task(self, **kwargs):
@@ -292,6 +292,7 @@ class Cases:
         iteration_name = self.iteration_meta_info.get('iteration_name')
         categories_map = self.excel.tapd.get_tapd_case_categories()
         test_plans_map = self.excel.tapd.get_tapd_test_plans()
+        stories_map = self.iteration_meta_info.get('iteration_stories', {})
 
         def html_format(content: str):
             return '<br />'.join(content.strip().splitlines())
@@ -340,8 +341,9 @@ class Cases:
 
                     if case_id:
                         # 创建测试计划和测试用例关联关系, 已关联过的用例不重复关联
-                        test_plan_id = test_plans_map.get(self.case_ws[story_cell].value)
-                        if test_plan_id:
+                        relation_story_id = stories_map.get(self.case_ws[story_cell].value)
+                        test_plan_id = test_plans_map.get(relation_story_id)
+                        if test_plan_id and not self.case_ws[case_id_cell].value:
                             self.excel.tapd.post_tapd_test_plans_and_tcase_relation(
                                 test_plan_id=test_plan_id,
                                 tcase_ids=case_id,
